<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de https://trad.spip.net/tradlang_module/spip_?lang_cible=br
// ** ne pas modifier le fichier **

return [

	// A
	'access_interface_graphique' => 'Distreiñ d’an etrefas grafek klok', # Gwelloc'h e vije ober gant etrefas evit treiñ interface; heñveldra, grafek zo kalz komprenusoc'h eget kevregañ. Dreist-holl e vez komprenet gant an holl hag en implij emañ gant kalz a dud
	'access_mode_texte' => 'diskouez an etrefas testenn eeun',
	'admin_debug' => 'dizreinañ',
	'admin_modifier_article' => 'Kemmañ ar pennad-mañ',
	'admin_modifier_auteur' => 'Kemmañ ar skridaozer-mañ',
	'admin_modifier_breve' => 'Kemmañ ar berrskrid-mañ',
	'admin_modifier_mot' => 'Kemmañ ar ger-stur-mañ',
	'admin_modifier_rubrique' => 'Kemmañ ar rubrikenn-mañ',
	'admin_recalculer' => 'Hizivaat ar bajenn',
	'afficher_calendrier' => 'Diskouez an deiziater',
	'afficher_trad' => 'diskouez an troidigezhioù',
	'alerte_maj_impossible' => '<b>Diwallit !</b> N’eus ket tu da hizivaat an diaz SQL etrezek ar stumm @version@, marteze abalamour d’ur gudenn aotre evit kemmañ an diaz titouroù. Mar plij kit e darempred gant ho herberc’hier.',
	'alerte_modif_info_concourante' => 'DIWALLIT : Kemmet eo bet an titour-mañ en ul lec’h all. Setu an talvoud nevez :',
	'analyse_xml' => 'Dielfennañ XML',
	'annuler' => 'Nullañ',
	'antispam_champ_vide' => 'Na lakait netra amañ :',
	'articles_recents' => 'Pennadoù nevesañ',
	'avis_1_erreur_saisie' => 'Ur fazi ho peus graet en ur skrivañ. Gwiriit ho testenn mar plij.',
	'avis_archive_incorrect' => 'N’eo ket ar restr diell ur restr SPIP',
	'avis_archive_invalide' => 'N’eo ket reizh ar restr diell',
	'avis_attention' => 'DIWALLIT !',
	'avis_champ_incorrect_type_objet' => 'Anv maezienn direizh @name@ evit un draezenn a seurt @type@',
	'avis_colonne_inexistante' => 'N’eus ket eus ar bann @col@',
	'avis_erreur' => 'Fazi: gwelet amañ a-is',
	'avis_erreur_connexion' => 'Fazi kevreañ',
	'avis_erreur_cookie' => 'kudenn toupin',
	'avis_erreur_fonction_contexte' => 'Fazi programmiñ. Arabat d’an arc’hwel-mañ bezañ galvet er gendestenn-mañ.',
	'avis_erreur_mysql' => 'Fazi SQL',
	'avis_erreur_sauvegarde' => 'Fazi er savete (@type@ @id_objet@) !',
	'avis_erreur_visiteur' => 'N’eus ket tu da dizhout al lodenn brevez',
	'avis_nb_erreurs_saisie' => 'Bez ez eus @nb@ fazi en ho skrid. Gwiriit ho testenn mar plij.',

	// B
	'barre_a_accent_grave' => 'Ouzhpennañ un A (pennlizherenn) gant un tired-boud warnañ',
	'barre_aide' => 'Implijit ar berradennoù tipografek evit pinvidikaat ar pajennaozañ',
	'barre_e_accent_aigu' => 'Ouzhpennañ un E (pennlizherenn) gant un tired-lemm warnañ',
	'barre_eo' => 'Ouzhpennañ un E en ’O’ (munud)',
	'barre_eo_maj' => 'Ouzhpennañ un E en O (pennlizherenn)',
	'barre_euro' => 'Ouzhpennañ an arouezenn €',
	'barre_gras' => 'Lakaat e {{druz}}',
	'barre_guillemets' => 'Gronnañ gant « krochedigoù »',
	'barre_guillemets_simples' => 'Gronnañ gant krochedigoù a eil live',
	'barre_intertitre' => 'Lakaat da {{{etretitl}}}',
	'barre_italic' => 'Lakaat en {italek}',
	'barre_lien' => 'Treiñ e [liamm gourskrid->http://...]',
	'barre_lien_input' => 'Merkit chomlec’h ho liamm (gallout a rit reiñ ar chomlec’h a-stumm gant  http://www.forzhpetra/com pe reiñ niverenn ur pennad eus al lec’hienn-mañ).',
	'barre_note' => 'Lakaat da [[Notenn traoñ-pajenn]]',
	'barre_paragraphe' => 'Krouiñ ur rannbennad',
	'barre_quote' => '<quote>Menegiñ ur gemennadenn</quote>',
	'bouton_changer' => 'Kemmañ',
	'bouton_chercher' => 'Klask',
	'bouton_choisir' => 'Dibab',
	'bouton_deplacer' => 'Dilec’hiañ ',
	'bouton_download' => 'Pellgargañ',
	'bouton_enregistrer' => 'Enrollañ',
	'bouton_radio_desactiver_messagerie_interne' => 'Diweredekaat ar postelerezh diabarzh',
	'bouton_radio_envoi_annonces' => 'Kas ar c’hemennoù embann',
	'bouton_radio_non_envoi_annonces' => 'Chom hep kas kemennoù',
	'bouton_radio_non_envoi_liste_nouveautes' => 'Chom hep kas roll an nevezinti',
	'bouton_recharger_page' => 'adkargañ ar bajenn-mañ',
	'bouton_telecharger' => 'Pellgargañ',
	'bouton_upload' => 'Pellgas',
	'bouton_valider' => 'Kadarnaat',

	// C
	'cal_apresmidi' => 'endervezh',
	'cal_jour_entier' => 'devezh a-bezh',
	'cal_matin' => 'beure',
	'cal_par_jour' => 'deiziataer deiz-ha-deiz',
	'cal_par_mois' => 'deiziataer miz-ha-miz',
	'cal_par_semaine' => 'deiziataer sizhun-ha-sizhun',
	'choix_couleur_interface' => 'liv',
	'choix_interface' => 'dibab an etrefas',
	'colonne' => 'Bann',
	'confirm_changer_statut' => 'Diwallit, goulennet hoc’h eus ma vo kemmet statud an elfenn-mañ. Ha mennet oc’h da genderc’hel ?',
	'correcte' => 'reizh',

	// D
	'date_aujourdhui' => 'hiziv',
	'date_avant_jc' => 'kent J.K.',
	'date_dans' => 'a-benn @delai@',
	'date_de_mois_1' => '@j@ @nommois@',
	'date_de_mois_10' => '@j@ @nommois@',
	'date_de_mois_11' => '@j@ @nommois@',
	'date_de_mois_12' => '@j@ @nommois@',
	'date_de_mois_2' => '@j@ @nommois@',
	'date_de_mois_3' => '@j@ @nommois@',
	'date_de_mois_4' => '@j@ @nommois@',
	'date_de_mois_5' => '@j@ @nommois@',
	'date_de_mois_6' => '@j@ @nommois@',
	'date_de_mois_7' => '@j@ @nommois@',
	'date_de_mois_8' => '@j@ @nommois@',
	'date_de_mois_9' => '@j@ @nommois@',
	'date_demain' => 'warc’hoazh',
	'date_fmt_heures_minutes' => '@h@eur@m@munut',
	'date_fmt_heures_minutes_court' => '@h@h@m@',
	'date_fmt_jour' => '@nomjour@ @jour@',
	'date_fmt_jour_heure' => '@jour@ da @heure@',
	'date_fmt_jour_heure_debut_fin' => '@jour@ adalek @heure_debut@ betek @heure_fin@',
	'date_fmt_jour_heure_debut_fin_abbr' => '@dtstart@@jour@ adalek @heure_debut@@dtabbr@ betek @dtend@@heure_fin@@dtabbr@',
	'date_fmt_jour_mois' => '@jour@ a viz @nommois@',
	'date_fmt_jour_mois_annee' => '@jour@ a viz @nommois@ @annee@',
	'date_fmt_mois_annee' => '@nommois@ @annee@',
	'date_fmt_nomjour' => '@nomjour@ @date@',
	'date_fmt_nomjour_date' => '@nomjour@ @date@',
	'date_fmt_periode' => 'Adalek @date_debut@ betek @date_fin@',
	'date_fmt_periode_abbr' => 'Adalek @dtart@@date_debut@@dtabbr@ betek @dtend@@date_fin@@dtabbr@',
	'date_fmt_periode_from' => 'Adalek',
	'date_fmt_periode_to' => 'betek',
	'date_fmt_saison_annee' => '@saison@ @annee@',
	'date_heures' => 'eur',
	'date_hier' => 'dec’h',
	'date_il_y_a' => '@delai@ zo',
	'date_jnum1' => '1añ',
	'date_jnum10' => '10',
	'date_jnum11' => '11',
	'date_jnum12' => '12',
	'date_jnum13' => '13',
	'date_jnum14' => '14',
	'date_jnum15' => '15',
	'date_jnum16' => '16',
	'date_jnum17' => '17',
	'date_jnum18' => '18',
	'date_jnum19' => '19',
	'date_jnum2' => 'eil',
	'date_jnum20' => '20',
	'date_jnum21' => '21',
	'date_jnum22' => '22',
	'date_jnum23' => '23',
	'date_jnum24' => '24',
	'date_jnum25' => '25',
	'date_jnum26' => '26',
	'date_jnum27' => '27',
	'date_jnum28' => '28',
	'date_jnum29' => '29',
	'date_jnum3' => '3',
	'date_jnum30' => '30',
	'date_jnum31' => '31',
	'date_jnum4' => '4',
	'date_jnum5' => '5',
	'date_jnum6' => '6',
	'date_jnum7' => '7',
	'date_jnum8' => '8',
	'date_jnum9' => '9',
	'date_jour_1' => 'Sul',
	'date_jour_1_abbr' => 'Sul',
	'date_jour_1_initiale' => 'S.',
	'date_jour_2' => 'Lun',
	'date_jour_2_abbr' => 'Lun',
	'date_jour_2_initiale' => 'L.',
	'date_jour_3' => 'Meurzh',
	'date_jour_3_abbr' => 'Meu.',
	'date_jour_3_initiale' => 'M.',
	'date_jour_4' => 'Merc’her',
	'date_jour_4_abbr' => 'Mer.',
	'date_jour_4_initiale' => 'M.',
	'date_jour_5' => 'Yaou',
	'date_jour_5_abbr' => 'Yaou',
	'date_jour_5_initiale' => 'Y.',
	'date_jour_6' => 'Gwener',
	'date_jour_6_abbr' => 'Gwe.',
	'date_jour_6_initiale' => 'Gw.',
	'date_jour_7' => 'Sadorn',
	'date_jour_7_abbr' => 'Sad.',
	'date_jour_7_initiale' => 'S.',
	'date_jours' => 'deiz',
	'date_minutes' => 'munut',
	'date_mois' => 'miz',
	'date_mois_1' => 'Genver',
	'date_mois_10' => 'Here',
	'date_mois_10_abbr' => 'here.',
	'date_mois_11' => 'Du',
	'date_mois_11_abbr' => 'du.',
	'date_mois_12' => 'Kerzu',
	'date_mois_12_abbr' => 'kerzu.',
	'date_mois_1_abbr' => 'genver.',
	'date_mois_2' => 'C’hwevrer',
	'date_mois_2_abbr' => 'c’hevrer.',
	'date_mois_3' => 'Meurzh',
	'date_mois_3_abbr' => 'Meurzh ',
	'date_mois_4' => 'Ebrel',
	'date_mois_4_abbr' => 'ebrel.',
	'date_mois_5' => 'Mae',
	'date_mois_5_abbr' => 'Mae',
	'date_mois_6' => 'Mezheven',
	'date_mois_6_abbr' => 'Mezheven',
	'date_mois_7' => 'Gouere',
	'date_mois_7_abbr' => 'gouere.',
	'date_mois_8' => 'Eost',
	'date_mois_8_abbr' => 'Eost',
	'date_mois_9' => 'Gwengolo',
	'date_mois_9_abbr' => 'gweng.',
	'date_saison_1' => 'Goañv',
	'date_saison_2' => 'nevez-amzer',
	'date_saison_3' => 'hañv',
	'date_saison_4' => 'diskar-amzer',
	'date_secondes' => 'eilenn',
	'date_semaines' => 'sizhun',
	'date_un_mois' => 'miz',
	'date_une_heure' => 'eur',
	'date_une_minute' => 'munut',
	'date_une_seconde' => 'eilenn',
	'date_une_semaine' => 'sizhun',
	'dirs_commencer' => 'a-benn kregiñ da vat gant ar staliadur',
	'dirs_preliminaire' => 'A-raok kenderc’hel : <b>Renkañ ar gwirioù moned</b>',
	'dirs_probleme_droits' => 'Kudenn gant ar gwirioù moned',
	'dirs_repertoires_absents' => '<p><b>N’eo ket bet kavet ar c’havlec’hioù-mañ : </b></p><ul>@bad_dirs@.</ul>
  <p>Posupl eo e vefe abalamour d’ur fazi impplij pennlizherennoù pe lizherennoù munut e lec’hioù fall.
  Gwiriit e klot mat stumm lizherennoù ar c’havlec’hioù gant ar pezh zo diskouezet a-us;
  ha ma ne glotont ket, adanvit anezho gant ho meziant FTP evit reizhañ ar gudenn.</p>
  <p>Ur wech graet an dra-se e c’hellot </p>',
	'dirs_repertoires_suivants' => '<p><b>N’haller ket skrivañ er c’havlec’hioù-mañ : </b></p><ul>@bad_dirs@.</ul>
  <p>Implijit ar meziant FTP a-benn kemmañ ar gwirioù evit pep hini.
  Displeget eo an hentenn er sturlevr staliañ.</p>
  <p>Ur wech graet se e c’helloc’h ',
	'double_occurrence' => '@balise@ bet kavet div wech',

	// E
	'en_cours' => 'war ober',
	'envoi_via_le_site' => 'Kas dre al lec’hienn',
	'erreur' => 'Fazi',
	'erreur_balise_non_fermee' => 'Balizenn ziwezhañ chomet digor :',
	'erreur_technique_ajaxform' => 'Gast !  Dre ur fazi dic’hortoz n’eus ket bet gellet kas ar furmenn. Klaskit ober en dro mar plij.

',
	'erreur_technique_enregistrement_champs' => 'Miret eo bet enrolliñ mat al heuliad-gerioù @champs@ abalamour d’ur fazi teknikel.',
	'erreur_technique_enregistrement_impossible' => 'Miret eo bet an enrolladenn abalamour d’ur fazi teknikel.',
	'erreur_texte' => 'fazi',
	'etape' => 'Pazenn',

	// F
	'fichier_introuvable' => 'Restr @fichier@ dibosupl da gavout', # MODIF
	'form_auteur_confirmation' => 'Gwirekait ho postel',
	'form_auteur_email_modifie' => 'Ho postel a zo bet kemmet.',
	'form_auteur_envoi_mail_confirmation' => 'Ur postel a wiriekadur a zo paouez bezañ kaset da @email@.  Ret eo deoc’h mont da welet ar chomlec’h merket e-barzh al lizher-se evit gwiriekaat ho postel.',
	'form_auteur_mail_confirmation' => 'Demat,

Goulennet ho peus cheñch ho postel. 
Evit gwiriekaat ho postel nevez, n’ho peus nemet kevreañ d’ar chomlec’h amañ dindan (e-giz-all e vo dianavezet ho koulenn) : 

    @url@
',
	'form_deja_inscrit' => 'Enskrivet oc’h c’hoazh.',
	'form_email_non_valide' => 'N’eo ket reizh ho postel.',
	'form_forum_access_refuse' => 'N’oc’h ket aotreet da vont war al lec’hienn-mañ ken.',
	'form_forum_bonjour' => 'Demat @nom@,',
	'form_forum_confirmer_email' => 'Evit gwiriekaat ho postel, mont d’ar chomlec’h :
@url_confirm@',
	'form_forum_email_deja_enregistre' => 'Enrollet eo ar postel-se dija. Gallout a rit ober gant ho ker-tremen boas neuze.',
	'form_forum_identifiant_mail' => 'Emañ ho kod moned nevez o paouez bezañ kaset deoc’h dre bostel.',
	'form_forum_identifiants' => 'Titouroù hiniennel',
	'form_forum_indiquer_nom_email' => 'Skrivit amañ hoc’h anv hag ho postel. Kaset e vo deoc’h buan ho titouroù hiniennel dre bostel.',
	'form_forum_login' => 'Kod kevreañ :',
	'form_forum_message_auto' => '(ur gemennadenn emgefre eo homañ)',
	'form_forum_pass' => 'ger-tremen :',
	'form_forum_probleme_mail' => 'Kudenn postel : n’haller ket kas an titouroù.',
	'form_forum_voici1' => 'Setu ho titouroù evit gallout kemer perzh e buhez "@nom_site_spip@" (@adresse_site@) :',
	'form_forum_voici2' => 'Setu ho titouroù evit gallout kinnig pennadoù war "@nom_site_spip@" (@adresse_login@) :',
	'form_indiquer_email' => 'Skrivit ho postel mar plij.',
	'form_indiquer_nom' => 'Skrivit hoc’h anv mar plij.',
	'form_indiquer_nom_site' => 'Skrivit anv ho lec’hienn.',
	'form_pet_deja_enregistre' => 'Enrollet eo al lec’hienn-mañ c’hoazh',
	'form_pet_signature_pasprise' => 'N’eus ket bet dalc’het kont eus ho sinadur.',
	'form_prop_confirmer_envoi' => 'Kadarnaat ar c’has',
	'form_prop_description' => 'Deskrivadur/evezhiadenn',
	'form_prop_enregistre' => 'Enrollet eo bet ho kinnig. Embannet e vo goude bezañ bet asantet gant tud e-karg eus al lec’hienn-mañ.', # MODIF
	'form_prop_envoyer' => 'Kas ur gemenadenn',
	'form_prop_indiquer_email' => 'Merkit ur postel reizh mar plij',
	'form_prop_indiquer_nom_site' => 'Merkit anv al lec’hienn.',
	'form_prop_indiquer_sujet' => 'Merkit ur sujed',
	'form_prop_message_envoye' => 'Kaset eo bet ar gemennadenn',
	'form_prop_non_enregistre' => 'N’eo ket bet enrollet ho kinnig',
	'form_prop_sujet' => 'Sujed',
	'form_prop_url_site' => 'Chomlec’h (URL) al lec’hienn',
	'format_date_incorrecte' => 'N’eo ket reizh an deiziad pe e stumm.',
	'format_heure_incorrecte' => 'N’eo ket reizh an eur pe he stumm.',
	'forum_non_inscrit' => 'N’oc’h ket enskrivet, pe direizh eo ar ger-tremen pe ar chomlec’h.',
	'forum_par_auteur' => 'gant @auteur@',
	'forum_titre_erreur' => 'Fazi...',

	// I
	'ical_texte_rss_articles' => 'D’ar chomlec’h-mañ emañ restr «backend» ar pennadoù :',
	'ical_texte_rss_articles2' => 'Gallout a rit kaout restroù «backend» evit pennadoù pep rummad al lec’hienn ivez :',
	'ical_texte_rss_breves' => 'Bez’ ez eus ivez ur restr enni berrskridoù al lec’hienn. Ma resisait niverenn ur rubrikenn, n’ho po nemet berrskridoù ar rubrikenn-se.',
	'icone_a_suivre' => 'Da genderc’hel',
	'icone_admin_site' => 'Merañ al lec’hienn',
	'icone_agenda' => 'Deiziataer',
	'icone_aide_ligne' => 'Skoazell',
	'icone_articles' => 'Pennadoù',
	'icone_auteurs' => 'Skridaozerien',
	'icone_brouteur' => 'Merdeiñ prim',
	'icone_configuration_site' => 'Kefluniañ ',
	'icone_configurer_site' => 'Kefluniañ ho lec’hienn',
	'icone_creer_nouvel_auteur' => 'Krouiñ ur skridaozer nevez',
	'icone_creer_rubrique' => 'Krouiñ ur rubrikenn',
	'icone_creer_sous_rubrique' => 'Krouiñ un isrubrikenn',
	'icone_deconnecter' => 'Digevreañ',
	'icone_discussions' => 'Kaozeadennoù',
	'icone_doc_rubrique' => 'Teulioù ar rubrikennoù',
	'icone_ecrire_article' => 'Skrivañ ur pennad nevez',
	'icone_edition_site' => 'Embann',
	'icone_gestion_langues' => 'Merañ ar yezhoù',
	'icone_informations_personnelles' => 'Titouroù hiniennel',
	'icone_interface_complet' => 'Etrefas klok',
	'icone_interface_simple' => 'Etrefas eeunaet',
	'icone_maintenance_site' => 'Ober war-dro al lec’hienn',
	'icone_messagerie_personnelle' => 'Postelerezh hiniennel',
	'icone_repartition_debut' => 'Diskouez an dasparzh abaoe an deroù',
	'icone_rubriques' => 'Rubrikennoù',
	'icone_sauver_site' => 'Saveteiñ al lec’hienn',
	'icone_site_entier' => 'Al lec’hienn a-bezh',
	'icone_sites_references' => 'Lec’hiennoù menegeret',
	'icone_statistiques' => 'Stadegoù al lec’hienn',
	'icone_suivi_activite' => 'Heuliañ buhez al lec’hienn',
	'icone_suivi_actualite' => 'Emdroadur al lec’hienn',
	'icone_suivi_pettions' => 'Heuliañ/merañ ar sinadegoù',
	'icone_suivi_revisions' => 'Kemmoù ar pennadoù',
	'icone_supprimer_document' => 'Diverkañ an teul-mañ',
	'icone_supprimer_image' => 'Diverkañ ar skeudenn-mañ',
	'icone_tous_articles' => 'Ho holl bennadoù',
	'icone_tous_auteur' => 'An holl skridaozerien',
	'icone_tous_visiteur' => 'An holl gweladerien',
	'icone_visiter_site' => 'Gweladenniñ al lec’hienn foran',
	'icone_voir_en_ligne' => 'Gwelet enlinenn',
	'img_indisponible' => 'skeudenn dibosupl da gaout',
	'impossible' => 'dibosupl',
	'info_a_suivre' => 'DA GENDERC’HEL»',
	'info_acces_interdit' => 'Difennet mont tre',
	'info_acces_refuse' => 'Nac’het eo bet deoc’h mon tre',
	'info_action' => 'Oberiadenn : @action@',
	'info_administrer_rubriques' => 'Gallout a rit merañ ar rubrikenn-mañ hag an isrubrikenndoù enni',
	'info_adresse_non_indiquee' => 'N’hoc’h eus ket lakaet chomlec’h ebet da arnodiñ !',
	'info_aide' => 'SKOAZELL :',
	'info_ajouter_mot' => 'Ouzhpennañ ar ger-mañ',
	'info_annonce' => 'KEMENN',
	'info_annonces_generales' => 'Kemennoù hollek :',
	'info_article_propose' => 'Pennad kinniget',
	'info_article_publie' => 'Pennad embannet',
	'info_article_redaction' => 'Pennad emeur o skridaozañ',
	'info_article_refuse' => 'Pennad nac’het',
	'info_article_supprime' => 'Pennad diverket',
	'info_articles' => 'Pennadoù',
	'info_articles_a_valider' => 'Ar pennadoù da gadarnaat',
	'info_articles_nb' => '@nb@ pennad-skrid',
	'info_articles_proposes' => 'Pennadoù kinniget',
	'info_articles_un' => '1 pennad',
	'info_auteurs_nombre' => 'skridaozer(ien) :',
	'info_authentification_ftp' => 'Gwiriañ (dre FTP).',
	'info_breves_2' => 'berrskridoù',
	'info_breves_nb' => '@nb@ pennadoù-berr',
	'info_breves_un' => '1 pennadig',
	'info_connexion_refusee' => 'Kevreañ nac’het',
	'info_contact_developpeur' => 'Kit e darempred gant un diorroer.', # MODIF
	'info_contenance' => 'El lec’hienn-mañ ez eus :',
	'info_contribution' => 'kenaozadurioù',
	'info_copyright' => 'Ur meziant dieub eo @spip@, dasparzhet @lien_gpl@.',
	'info_copyright_doc' => 'Evit titouroù ouzhpenn, gwelet al lec’hienn <a href="@spipnet@">@spipnet_affiche@</a>.',
	'info_copyright_gpl' => 'dindan aotre implijout GPL',
	'info_cours_edition' => 'Ar pennadoù emaoc’h o skrivañ', # MODIF
	'info_creer_repertoire' => 'Krouit ur restr pe ur c’havlec’h anvet :',
	'info_creer_repertoire_2' => 'en iskavlec’h <b>@repertoire@</b>, ha :',
	'info_creer_vignette' => 'krouiñ emgefreek ar skeudennig',
	'info_creerdansrubrique_non_autorise' => 'N’ho peus trawalc’h a wirioù evit krouiñ danvez er rubrikenn-mañ.',
	'info_deplier' => 'Displegañ',
	'info_descriptif_nombre' => 'deskrivadur(ioù) :',
	'info_description' => 'Deskrivadur :',
	'info_description_2' => 'Deskrivadur :',
	'info_dimension' => 'Ment :',
	'info_documents_nb' => '@nb@ diell',
	'info_documents_un' => '1 diell',
	'info_ecire_message_prive' => 'Skrivañ ur gerig prevez;',
	'info_email_invalide' => 'Postel direizh.',
	'info_en_cours_validation' => 'Ar pennadoù emaoc’h o skrivañ',
	'info_en_ligne' => 'Enlinenn evit poent :',
	'info_envoyer_message_prive' => 'Kas ur gerig prevez d’ar skridaozer-mañ',
	'info_erreur_requete' => 'Fazi er reked :',
	'info_erreur_squelette2' => 'N’eus framm <b>@fichier@</b> ebet da gaout...',
	'info_erreur_systeme' => 'Fazi reizhiad (errno @errsys@)',
	'info_erreur_systeme2' => 'Marteze eo leun-chouk ar bladenn-galet, pe neuze eo mazaouet an diaz titouroù.<br />
<span style="color:red;">Klaskit <a href=\'@script@\'>ratreañ an diaz</a>, pe kit e darempred gant an herberc’hier.</span>',
	'info_fini' => 'Echu eo !',
	'info_format_image' => 'Furmadoù skeudenn a c’hell bezañ implijet da sevel skeudennigoù : @gd_formats@.',
	'info_format_non_defini' => 'Stumm didermenet',
	'info_grand_ecran' => 'Skramm bras',
	'info_image_aide' => 'SKOAZELL',
	'info_image_process_titre' => 'Hentenn da grouiñ skeudennigoù',
	'info_impossible_lire_page' => '<b>Fazi !</b> Dibosupl eo lenn ar bajenn <tt><html>@test_proxy@</html></tt> dre ar proksi',
	'info_installation_systeme_publication' => 'O staliañ ar reizhiad embann...',
	'info_installer_documents' => 'Gallout a rit staliañ en un doare emgefreek an holl deulioù zo en teuliad @upload@.',
	'info_installer_ftp' => 'Dre ma’z oc’h merour e c’hellit staliañ restroù (dre FTP) en teuliad @upload@ deoc’h da c’hallout ober ganto amañ da c’houde.', # MODIF
	'info_installer_images' => 'Er furmadoù JPEG, GIF ha PNG e c’hellit staliañ skeudennoù.',
	'info_installer_images_dossier' => 'Staliañ skeudennoù en teuliad @upload@ evit gallout o diuzañ amañ.',
	'info_interface_complete' => 'Etrefas klok',
	'info_interface_simple' => 'Etrefas eeunaet',
	'info_joindre_document_article' => 'Teulioù a eurt-se a c’hellit stagañ ouzh ar pennad-mañ :',
	'info_joindre_document_rubrique' => 'Teulioù a seurt-se a c’hellit stagañ ouzh ar rubrikenn-mañ :',
	'info_joindre_documents_article' => 'Teulioù a seurt-se a c’hellit stagañ ouzh ho pennad :',
	'info_l_article' => 'ar pennad',
	'info_la_breve' => 'ar berrskrid',
	'info_la_rubrique' => 'ar rubrikenn',
	'info_langue_principale' => 'Yezh pennañ al lec’hienn',
	'info_largeur_vignette' => '@largeur_vignette@ × @hauteur_vignette@ piksel',
	'info_les_auteurs_1' => 'gant @les_auteurs@',
	'info_logo_format_interdit' => 'Er furmad @formats@ hepken e vez aotreet al logoioù.',
	'info_logo_max_poids' => 'Nebeutoc’h eget @maxi@ e rank al logoioù bezañ (@actuel@ eo ar restr-mañ).',
	'info_mail_fournisseur' => 'hoc’hanv@herberc’hier.com',
	'info_message_2' => 'KEMENNADENN',
	'info_message_supprime' => 'KEMENNADENN BET DIVERKET',
	'info_messages_nb' => '@nb@ kemennadennoù',
	'info_messages_un' => '1 gemennadenn',
	'info_mise_en_ligne' => 'Lakaet war ar rouedad d’an :',
	'info_modification_parametres_securite' => 'kemm an arventennoù surentez',
	'info_mois_courant' => 'E-kerzh ar miz :',
	'info_mot_cle_ajoute' => 'Ar ger-stur-mañ zo bet ouzhpennet',
	'info_multi_herit' => 'Yezh dre ziouer',
	'info_multi_langues_soulignees' => 'Ar <u>yezhoù islinennet</u> zo bet troet holl destennoù an etrefas enne. Ma tibabit ar yezhoù-se e vo troet ul lodenn vat eus elfennoù al lec’hienn (deiziadoù, furmskridoù, hag all) en un doare otomatek. Evit ar yezhoù n’int ket islinennet e vo an elfennoù-se e yezh pennañ al lec’hienn.',
	'info_multilinguisme' => 'Liesyezhegezh',
	'info_nom_non_utilisateurs_connectes' => 'N’emañ ket hoc’h  anv war roll an implijerien kevreet.', # MODIF
	'info_nom_utilisateurs_connectes' => 'Gwelet e vez hoc’h anv war roll an implijerien kevreet.', # MODIF
	'info_nombre_en_ligne' => 'Bremañ war al lec’hienn :',
	'info_non_resultat' => 'Disoc’h ebet evit "@cherche_mot@"',
	'info_non_utilisation_messagerie' => 'N’implijit ket postelerezh diabarzh al lec’hienn-mañ.',
	'info_nouveau_message' => 'UR GEMENNADENN NEVEZ HOC’H EUS BET',
	'info_nouveaux_messages' => '@total_messages@ KEMENNADENN NEVEZ HOC’H EUS BET',
	'info_numero_abbreviation' => 'Niv. ',
	'info_obligatoire' => 'Ret eo deoc’h reiñ an titour-mañ',
	'info_pense_bete' => 'NOTENNIG-EÑVOR',
	'info_petit_ecran' => 'Skramm bihan',
	'info_petition_close' => 'Kloz eo ar sinadeg',
	'info_pixels' => 'piksel',
	'info_plusieurs_mots_trouves' => 'Meur a c’her-stur zo bet kavet evit "@cherche_mot@":',
	'info_portfolio_automatique' => 'Portfolio emgefre :',
	'info_premier_resultat' => '[@debut_limit@ disoc’h kentañ diwar @total@]',
	'info_premier_resultat_sur' => '[@debut_limit@ disoc’h kentañ diwar @total@]',
	'info_propose_1' => '[@nom_site_spip@] a ginnig : @titre@',
	'info_propose_2' => 'Pennad bet kinniget
---------------',
	'info_propose_3' => 'Kinnig a reer embann ar pennad "@titre@".',
	'info_propose_4' => 'Pedet oc’h da zont d’e lenn ha da reiñ hoc’h ali',
	'info_propose_5' => 'er forom stag outañ. Kavet e vo er chomlec’h-mañ :',
	'info_publie_01' => 'Kadarnaet eo bet ar pennad "@titre@" gant @connect_nom@.',
	'info_publie_1' => '[@nom_site_spip@] A EMBANN : @titre@',
	'info_publie_2' => 'Pennad embannet
--------------',
	'info_rechercher' => 'Klask',
	'info_rechercher_02' => 'Klask :',
	'info_remplacer_vignette' => 'Erlec’hiañ ar skeudennig dre ziouer gant ul logo deoc’h :',
	'info_rubriques_nb' => '@nb@ rubrikenn',
	'info_rubriques_un' => '1 rubrikenn',
	'info_sans_titre_2' => 'titl ebet',
	'info_selectionner_fichier' => 'Gallout a rit diuzañ ur restr eus an teuliad @upload@',
	'info_selectionner_fichier_2' => 'Diuzañ ur restr :',
	'info_sites_nb' => '@nb@ lec’hienn',
	'info_sites_un' => '1 lec’hienn',
	'info_supprimer_vignette' => 'diverkañ ar skeudennig',
	'info_symbole_bleu' => 'Talvezout a ra an arouez <b>glas</b> evit un <b>notennig-eñvor</b>: da lavaret eo ur gemennadenn evidoc’h hepken.',
	'info_symbole_jaune' => 'Talvezout a ra an arouez <b>melen</b> evit ur <b>c’hemenn d’an holl skridaozerien</b> : a c’hell bezañ kemmet gant ur merour ha lennet gant an holl skridaozerien.', # MODIF
	'info_symbole_vert' => 'Talvezout a ra an arouez <b>gwer</b> evit ar <b>c’hemennadennoù bet eskemmet etre implijerien all</b> al lec’hienn.', # MODIF
	'info_telecharger_nouveau_logo' => 'Pellgargañ ul logo nevez :',
	'info_telecharger_ordinateur' => 'Pellgargañ adal hoc’h urzhiataer :',
	'info_tous_resultats_enregistres' => '[enrollet e vez an holl discoc’hoù]',
	'info_tout_afficher' => 'Diskouez pep tra',
	'info_travaux_texte' => 'N’eo ket bet kefluniet al lec’hienn evit c’hoazh. Distroit a-benn nebeut...',
	'info_travaux_titre' => 'Emeur o sevel al lec’hienn',
	'info_trop_resultat' => 'Re a zisoc’hoù evit "@cherche_mot@"; resisait termenoù hoc’h enklask mar plij.',
	'info_utilisation_messagerie_interne' => 'Ober a rit gant postelerezh diabarzh al lec’hienn-mañ.',
	'info_valider_lien' => 'kadarnaat al liamm-mañ',
	'info_verifier_image' => 'gwiriit eo bet treuzkaset mat ho skeudennoù.',
	'info_vignette_defaut' => 'Skeudennig dre ziouer',
	'info_vignette_personnalisee' => 'skeudennig personelaet',
	'info_visite' => 'gweladenn :',
	'info_vos_rendez_vous' => 'Hoc’h emgavioù da zont',
	'infos_vos_pense_bete' => 'Ho notennigoù-eñvor',

	// L
	'label_ajout_id_rapide' => 'Ouzhpennet buan',
	'label_poids_fichier' => 'Ment',
	'lien_afficher_icones_seuls' => 'Diskouez ar skeudennigoù hepken',
	'lien_afficher_texte_icones' => 'Diskouez ar skeudennigoù hag an destenn',
	'lien_afficher_texte_seul' => 'Diskouez an destenn hepken',
	'lien_liberer' => 'dieubiñ',
	'lien_liberer_tous' => 'Dinaskañ an holl',
	'lien_nouvea_pense_bete' => 'NOTENNIG-EÑVOR NEVEZ',
	'lien_nouveau_message' => 'KEMENNADENN NEVEZ',
	'lien_nouvelle_annonce' => 'KEMENN NEVEZ',
	'lien_petitions' => 'SINADEG',
	'lien_popularite' => 'brud : @popularite@%',
	'lien_racine_site' => 'GWRIZIENN AL LEC’HIENN',
	'lien_reessayer' => 'klask en-dro',
	'lien_repondre_message' => 'Repont d’ar gemennadenn-mañ',
	'lien_supprimer' => 'diverkañ',
	'lien_tout_afficher' => 'Diskouez pep tra',
	'lien_visite_site' => 'gweladenniñ al lec’hienn-mañ',
	'lien_visites' => '@visites@ gweladenn',
	'lien_voir_auteur' => 'Gwelet ar skridaozer-mañ',
	'ligne' => 'Linenn',
	'login' => 'Kevreañ',
	'login_acces_prive' => 'tizhout al lodenn brevez',
	'login_autre_identifiant' => 'Kevreañ gant ur c’hod anaout all',
	'login_cookie_accepte' => 'Grit ar pezh zo ezhomm evit ma vint degemeret gant ho merdeer, evit al lec’hienn-mañ d’an nebeutañ',
	'login_cookie_oblige' => 'Evit kevreañ en un doare sur war al lec’hienn-mañ e rankit degemer an toupinoù.',
	'login_deconnexion_ok' => 'Digevreet oc’h.',
	'login_erreur_pass' => 'Fazi ger-tremen.',
	'login_espace_prive' => 'lodenn brevez',
	'login_identifiant_inconnu' => 'N’eo ket anavezet ar c’hoad anaout « @login@ ».',
	'login_login' => 'Kod kevreañ :',
	'login_login2' => 'Login pe postel :',
	'login_login_pass_incorrect' => '(direizh eo ar c’hod kevreañ pe ar ger-tremen)',
	'login_motpasseoublie' => 'ankouaet ho ker-tremen ganeoc’h ?',
	'login_non_securise' => 'Diwallit, n’eo ket suraet ar furmskrid-mañ.
   Ma ne fell ket deoc’h e c’hellfe ho ker-tremen bezañ pesketet
   war ar rouedad, gweredekait Javascript en ho merdeer ha',
	'login_nouvelle_tentative' => 'Klask en-dro',
	'login_par_ici' => 'Enrollet oc’h...dre amañ...',
	'login_pass2' => 'Ger-tremen :',
	'login_preferez_refuser' => '<b>Ma kavit gwell nac’hañ an toupinoù</b>, e c’hellit ober gant un doare all da gevreañ, met n’eo ket ken asur :',
	'login_recharger' => 'adkargañ ar bajenn-mañ',
	'login_rester_identifie' => 'Chom anavezet un nebeud devezhioù', # MODIF
	'login_retour_public' => 'Distreiñ d’al lodenn foran',
	'login_retour_site' => 'Distreiñ d’al lodenn foran',
	'login_retoursitepublic' => 'distreiñ d’al lodenn foran',
	'login_sans_cookie' => 'Kevreañ hep toupinoù',
	'login_securise' => 'Login diogelet',
	'login_sinscrire' => 'en em enskrivañ', # MODIF
	'login_test_navigateur' => 'taol-arnod merdeer/adkevreañ',
	'login_verifiez_navigateur' => '(Gwiriit memes tra n’eo ket bet memoret ho ker-tremen gant ar merdeer...)',

	// M
	'masquer_colonne' => 'Kuzhat ar bann-mañ',
	'masquer_trad' => 'kuzhat an troidigezhioù',
	'message_nouveaux_identifiants_echec' => 'N’heller ket krouiñ anvioù implijer nevez.',
	'message_nouveaux_identifiants_echec_envoi' => 'N’eo ket bet kaset an anvioù  implijer nevez evit kevreañ.',
	'message_nouveaux_identifiants_ok' => 'Kaset eo bet an anvioù implijer nevez evit kevreañ da @email@.',
	'module_fichiers_langues' => 'Restroù yezh',

	// N
	'navigateur_pas_redirige' => 'Klikit amañ evit kederc’hel ma ne vez ket adheñchet ho merdeer.',
	'numero' => 'Niverenn',

	// O
	'occurence' => 'Kavadenn',
	'onglet_affacer_base' => 'Diverkañ an diaz',
	'onglet_auteur' => 'Ar skridaozer',
	'onglet_contenu_site' => 'Endalc’had al lec’hienn',
	'onglet_evolution_visite_mod' => 'Emdroadur',
	'onglet_fonctions_avances' => 'Arc’hwelioù kemplezh',
	'onglet_informations_personnelles' => 'Titouroù hiniennel',
	'onglet_interactivite' => 'Etreobererezh',
	'onglet_messagerie' => 'Postelerezh',
	'onglet_repartition_rubrique' => 'Dasparzh diouzh ar rummad',
	'onglet_save_restaur_base' => 'Saveteiñ/Assevel an diaz',
	'onglet_vider_cache' => 'Goullonderiñ ar grubuilh',

	// P
	'pass_choix_pass' => 'Dibabit ho ker-tremen nevez :',
	'pass_erreur' => 'Fazi',
	'pass_erreur_acces_refuse' => '<b>Fazi :</b> n’hoc’h ket aotreet da zont war al lec’hienn-mañ ken.',
	'pass_erreur_code_inconnu' => '<b>Fazi :</b> ne glot ar c’hod-mañ gant gweladenner ebet a c’hall mont war al lec’hienn-mañ.', # MODIF
	'pass_erreur_non_enregistre' => '<b>Fazi :</b>n’eo ket enrollet ar chomlec’h <tt>@email_oubli@</tt> war al lec’hienn-mañ.',
	'pass_erreur_non_valide' => '<b>Fazi :</b> n’eo ket reizh ar postel <tt>@email_oubli@</tt> !',
	'pass_erreur_probleme_technique' => '<b>Fazi :</b> abalamout d’u gudenn deknikel, ne c’hell ket ar postel bezañ kaset.',
	'pass_espace_prive_bla' => 'Dav eo bezañ enskrivet a-raok gallout tizhout lodenn brevez al lec’hienn.
  P aviot enrollet e c’hellot lenn ar pennadoù meeur o skrivañ, kinnig pennadoù, ha kemer perzh er foromoù.', # MODIF
	'pass_forum_bla' => 'Goulennet hoc’h eus gallout kemer perzh war ur forom n’hall nemet an implijerien enrollet skrivañ warnañ.', # MODIF
	'pass_indiquez_cidessous' => 'Skrivit amañ dindan ar postel a oa bet implijet ganeoc’h evit en em enrollañ.
   Ur postel a vo kaset deoc’h ennañ an titouroù ret evit gallout dont en-dro war al lec’hienn.',
	'pass_mail_passcookie' => '(ur gemennadenn emgefre eo homañ)
Evit gallout distreiñ war al lec’hienn
@nom_site_spip@ (@adresse_site@)

Kit d’ar chomlec’h-mañ :

    @sendcookie@

Neuze e c’hellot merkañ ur ger-tremen nevez ha
kevreañ en-dro ouzh al lec’hienn.

', # Connecter : gwelloc'h eo ober gant kevreañ zo muioc'h en implij gant an dud. Kevreañ ouzh ar genrouedad hag all. MODIF
	'pass_mot_oublie' => 'Ankouaet ar ger-tremen',
	'pass_nouveau_enregistre' => 'Enrollet eo bet ho ker-tremen nevez.',
	'pass_nouveau_pass' => 'Ger-tremen nevez',
	'pass_ok' => 'MAT EO',
	'pass_oubli_mot' => 'Ankouaet ar ger-tremen',
	'pass_procedure_changer' => 'Evit kemmañ ho ker-tremen e rankomp gwiriekaat piv oc’h. Evit en ober diskouezit deomp ar postel liammet gant ho kont.',
	'pass_quitter_fenetre' => 'Kuitaat ar prenestr-mañ',
	'pass_rappel_login' => 'Dalc’hit soñj : « @login@ » eo ho anv-tremen (login).',
	'pass_recevoir_mail' => 'Ur postel a vo kaset deoc’h, ennañ an titouroù ret da c’hallout tizhout al lec’hienn en-dro.', # MODIF
	'pass_retour_public' => 'Distreiñ d’al lodenn foran',
	'pass_rien_a_faire_ici' => 'Netra d’ober amañ.',
	'pass_vousinscrire' => 'En em enskrivañ war al lec’hienn-mañ',
	'precedent' => 'kent',
	'previsualisation' => 'Rakwelet',
	'previsualiser' => 'Rakwelet',

	// R
	'retour' => 'Distreiñ',

	// S
	'spip_conforme_dtd' => 'SPIP a gav dezhañ e klot an teul-mañ gant e DOCTYPE :',
	'squelette' => 'framm',
	'squelette_inclus_ligne' => 'framm e-barzh, linenn',
	'squelette_ligne' => 'framm, linenn',
	'stats_visites_et_popularite' => '@visites@ gweladenn ; brud; : @popularite@',
	'suivant' => 'war-lerc’h',

	// T
	'taille_go' => '@taille@ Go',
	'taille_ko' => '@taille@ ke',
	'taille_mo' => '@taille@ Me',
	'taille_octets' => '@taille@ eizhbit',
	'taille_octets_bi' => '@taille@ eizhbit',
	'texte_actualite_site_1' => 'Pa viot boas ouzh an etrefas e c’hellot klikañ war «',
	'texte_actualite_site_2' => 'etrefas klok',
	'texte_actualite_site_3' => '» evit sevijoù ouzhpenn.',
	'texte_creation_automatique_vignette' => 'Ober a reer gant ar sevel skeudennigoù adal skeudennoù. Ma stailhi skeudennoù er furmad(où) @gd_formats@, adal ar furmskrid-mañ e vo staget ur skeudennig @taille_preview@ piksel d’ar muiañ outo.',
	'texte_documents_associes' => 'Stag eo an teulioù-mañ ouzh ar pennad,
    met n’int ket bet ensoc’het diouzhtu ennañ
    Diouzh mod pajennaozañ al lec’hienn e c’hellint bezañ diskouezet dindan stumm restroù stag.',
	'texte_erreur_mise_niveau_base' => 'Ur fazi zo bet gant an diaz titouroù en ur hizivaat.
  N’eo ket tremenet ar skeudenn <b>@fichier@</b> (pennad @id_article@).
  Notennit an daveenn-se, klaksit hizivaat en-dro, 
  ha gwiriit e vez diskouezet ar skeudennoù er pennadoù.',
	'texte_erreur_visiteur' => 'Klasket hoc’h eus tizhout al lodenn brevez gant un anv implijer direizh.',
	'texte_inc_auth_1' => 'Enrollet oc’h dindan al ger kevreañ
 <b>@auth_login@</b>, met n’eus ket anezhañ (ken) en diaz titouroù.
  Klaskit ',
	'texte_inc_auth_2' => 'adkevreañ',
	'texte_inc_auth_3' => ', goude bezañ kuitaet hag adloc’het ho merdeer.',
	'texte_inc_config' => '>Ul levezon vras o deus kemmoù ar bajenn-mañ war mont en-dro hollek al lec’hienn.
Aliet oc’h da chom hep kemmañ tra ebet e-keit ha n’oc’h ket boas ouzh SPIP.
 <br /><br /><b>Aliet oc’h da lezel webmestr pennañ al lec’hienn ober war-dro ar pajennoù-mañ.</b>',
	'texte_inc_meta_1' => 'Ur fazi zo bet en ur skrivañ war ar restr <code>@fichier@</code>. Dre ma’z oc’h merour al lec’hienn e rankit ', # MODIF
	'texte_inc_meta_2' => 'Gwiriañ ar gwirioù da skrivañ ',
	'texte_inc_meta_3' => 'war ar c’havlec’h <code>@repertoire@</code>.',
	'texte_statut_en_cours_redaction' => 'o skridaozañ',
	'texte_statut_poubelle' => 'er pod-lastez',
	'texte_statut_propose_evaluation' => 'kinniget ouzh an amprou',
	'texte_statut_publie' => 'embannet',
	'texte_statut_refuse' => 'nac’het',
	'titre_ajouter_mot_cle' => 'OUZHPENNAÑ UR GER-STUR :',
	'titre_cadre_raccourcis' => 'BERRADENNOÙ :',
	'titre_changer_couleur_interface' => 'Kemm liv an etrefas',
	'titre_image_admin_article' => 'Gallout a rit merañ ar pennad-mañ',
	'titre_image_administrateur' => 'Merour', # MODIF
	'titre_image_aide' => 'Skoazell diwar-benn an elfenn-mañ',
	'titre_image_auteur_supprime' => 'Skridaozer bet diverket',
	'titre_image_redacteur' => 'Skridaozer hep aotre moned',
	'titre_image_redacteur_02' => 'Skridaozer',
	'titre_image_selecteur' => 'Diskouez al listenn',
	'titre_image_visiteur' => 'Gweladenner',
	'titre_joindre_document' => 'STAGAÑ UN TEUL',
	'titre_mots_cles' => 'GERIOÙ-STUR',
	'titre_probleme_technique' => 'Diwallit : abalamour d’ur gudenn deknikel (servijer SQL), n’eus ket tu da dizhout al lodenn-mañ eus al lec’hienn. Trugarez evit ho komprenezon.',
	'titre_publier_document' => 'EMBANN UN TEUL ER RUBRIKENN-MAÑ',
	'titre_signatures_attente' => 'Sinadurioù a c’hortoz bezañ kadarnaet',
	'titre_signatures_confirmees' => 'Sinadurioù bet gwiriekaet',
	'titre_statistiques' => 'Stadegoù al lec’hienn', # Stadegoù, termen skoueriekaet gant TermBret evit Statistiques.
	'titre_titre_document' => 'Titl an teul :',
	'todo' => 'da zont',
	'trad_definir_reference' => 'Dibab "@titre@" evel dave an troidigezhioù',
	'trad_reference' => '(Pennad diazez evit an troidigezhioù)',

	// U
	'upload_limit' => 'Re bounner eo ar fichennaoueg-mañ evit ar servijer ; brasañ ment aotreet e <i>upload</i> a zo @max@.',

	// Z
	'zbug_balise_b_aval' => ' : balizenn B en ardraoñ',
	'zbug_balise_inexistante' => 'Disklêriet-fall eo ar valizenn @balise@ evit @from@',
	'zbug_balise_sans_argument' => 'Un arguzenn a vank er valizenn @balise@',
	'zbug_boucle' => 'bouklenn',
	'zbug_boucle_recursive_undef' => 'N’eo ket bet termenet ar vouklenn-mañ : @nom@',
	'zbug_calcul' => 'jediñ',
	'zbug_champ_hors_boucle' => 'Maezienn @champ@ e diavaez ar vouklenn',
	'zbug_champ_hors_motif' => 'Maezienn @champ@ er-maez kendestenn @motif@',
	'zbug_code' => 'kod',
	'zbug_critere_inconnu' => 'Dezverk @critere@ dianav',
	'zbug_critere_sur_table_sans_cle_primaire' => '{@critere@} war un daolenn hep alc’hwez kentael atomek',
	'zbug_distant_interdit' => 'N’eo ket posupl war un diaz roadoù diavaez',
	'zbug_doublon_table_sans_cle_primaire' => 'Doublennoù war un diaz hep alc’hwez kentañ atomek',
	'zbug_doublon_table_sans_index' => 'Doublenn war un diaz hep meneger',
	'zbug_erreur_boucle_double' => 'Bouklenn @id@ bet termenet div wech',
	'zbug_erreur_boucle_fermant' => 'Chomet eo digor ar vouklenn @id@',
	'zbug_erreur_boucle_syntaxe' => 'Direizh eo ereadurezh  ar vouklenn  @id@',
	'zbug_erreur_compilation' => 'Fazi kempunañ',
	'zbug_erreur_execution_page' => 'Fazi erounit',
	'zbug_erreur_filtre' => 'Sil @filtre@ didermenet',
	'zbug_erreur_meme_parent' => 'n’hall an dezverk {meme_parent} bezañ implijet nemet war ar bouklennoù (FOROMOÙ) pe (RUBRIKENNOÙ)',
	'zbug_erreur_squelette' => 'Fazi(où) er framm',
	'zbug_hors_compilation' => 'Er-maez kempunad',
	'zbug_info_erreur_squelette' => 'Fazi war al lec’hienn',
	'zbug_inversion_ordre_inexistant' => 'Eilpennañ un urzh n’eus ket anezhañ',
	'zbug_pagination_sans_critere' => 'N’eus dezverk ebet d’ar valizenn #PAJENNAOUIÑ, pe neuze eo implijet en ur vouken a dro warni hec’h-unan',
	'zbug_parametres_inclus_incorrects' => 'Direizh eo an arventenn ensoc’hañ @param@',
	'zbug_profile' => 'Amzer jediñ : @time@',
	'zbug_resultat' => 'disoc’h',
	'zbug_serveur_indefini' => 'Servijer SQL didermenet',
	'zbug_statistiques' => 'Stadegoù ar goulennoù SQL urzhiet diouzh o fad',
	'zbug_table_inconnue' => 'Taolenn SQL « @table@ » dianav',
	'zxml_connus_attributs' => 'perzhioù anavezet',
	'zxml_de' => 'da',
	'zxml_inconnu_attribut' => 'perzh dianav',
	'zxml_inconnu_balise' => 'balizenn dianav',
	'zxml_inconnu_entite' => 'elfenn dianav',
	'zxml_inconnu_id' => 'ID dianav',
	'zxml_mais_de' => 'met eus',
	'zxml_non_conforme' => 'ne glot ket gant an abeg',
	'zxml_non_fils' => 'n’eo ket ur mab da',
	'zxml_nonvide_balise' => 'balizenn ket goullo',
	'zxml_obligatoire_attribut' => 'perzh rediet, met na gaver ket e',
	'zxml_succession_fils_incorrecte' => 'heuliad ar vibien direizh',
	'zxml_survoler' => 'tremen buan da welet ar re zo reizh',
	'zxml_valeur_attribut' => 'talvoudegezh ar perzh',
	'zxml_vide_balise' => 'balizenn c’houllo',
	'zxml_vu' => 'bet gwelet a-raok',
];
